@@ -16,9 +16,11 @@ async fn main() {
     let router1 = Router::new().get(hello_world1);
     let router2 = Router::new().get(hello_world2);
 
+    tracing::info!("Listening on http://127.0.0.1:7878");
+    tracing::info!("Listening on http://127.0.0.1:7979");
     tokio::try_join!(
-        Server::new(TcpListener::bind("0.0.0.0:7878")).try_serve(router1),
-        Server::new(TcpListener::bind(([0, 0, 0, 0], 7979))).try_serve(router2),
+        Server::new(TcpListener::bind("127.0.0.1:7878")).try_serve(router1),
+        Server::new(TcpListener::bind("127.0.0.1:7979")).try_serve(router2),
     )
     .unwrap();
 }
